..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

============
 Invenio-DB
============

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-db.svg
        :target: https://github.com/inveniosoftware/invenio-db/blob/master/LICENSE

.. image:: https://img.shields.io/travis/inveniosoftware/invenio-db.svg
        :target: https://travis-ci.org/inveniosoftware/invenio-db

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-db.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-db

.. image:: https://img.shields.io/pypi/v/invenio-db.svg
        :target: https://pypi.org/pypi/invenio-db


Database management for Invenio.
Further documentation available on https://invenio-db.readthedocs.io/
